<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Esc</name>
    <message>
        <location filename="../EscInit.js" line="+2"/>
        <source>&amp;Escape</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Anuluj</translation>
    </message>
</context>
</TS>
